const mongoose = require('mongoose');
const Access = require('../models/accessSchema'); 

require('dotenv').config({ path: '../../.env' }); 


// Connect to MongoDB
console.log( 's', process.env.MONGODB_URI);
mongoose.connect(process.env.MONGODB_URI);

const db = mongoose.connection;
db.on('error', console.error.bind(console, 'MongoDB connection error:'));

// Data to seed
const accessData = [
  {
    role: 'Super Admin',
    board: {
      activeProjects: true,
      team: true,
      resourcesOnBench: true,
      requestForResources: true,
      requestForResourcesAllocate: true,
      requestForExtensionApproveReject: true,
      myActions: true,
      alerts: true
    },
    timesheet: {
      viewTimesheet: true,
      addTimeEntry: true,
      editTrackedOrEnteredTime: true,
      deleteTimesheet: true,  
      trackTime: true,
      approveOrRejectTimesheet: true,
      submitTimesheet: true
    },  
    projects: {
      projectsListingActive: true,
      addProjects: true,
      editProjects: true,
      deleteProjects: true,
      projectsListingClosed: true,
      closeOfProject: true,
      reopenClosedProjects: true,
      viewTeam: true,
      addTeam: true,
      editTeam: true,
      deleteTeam: true,
      requestForAdditionalResources: true,
      requestForResourceApproveReject: true,
      requestForExtension: true,
      requestForExtensionApproveReject: true,
      viewMilestone: true,
      addMilestone: true,
      editMilestone: true,
      deleteMilestone: true,
      viewSkillset: true,
      addSkillset: true,
      deleteSkillset: true,
      viewCRFR: true,
      addCRFR: true,
      editCRFR: true,
      deleteCRFR: true,
      historyViewAll: true,
      historyViewAllocation: true,
      historyViewExtension: true
    },
    team: {
      viewTeamListing: true,
      addNewTeamMember: true,
      editTeam: true,
      deleteTeam: true
    },
    report:{
      employeeTimesheetReport : true,
      estimatedVsActualReport : true,
    },
    skillset: {
      viewSkillsetListing: true,
      addNewSkillset: true,
      deleteSkillset: true,
      editSkillset: true
    },
    rolesAndAccess: {
      setAccessForDifferentRoles: true
    }
  },
  {
    role: 'TAM',
    board: {
      activeProjects: false,
      team: false,
      resourcesOnBench: false,
      requestForResources: false,
      requestForResourcesAllocate: false,
      requestForExtensionApproveReject: false,
      myActions: true,
      alerts: true
    },
    timesheet: {
      viewTimesheet: true,
      addTimeEntry: true,
      editTrackedOrEnteredTime: true,
      deleteTimesheet: true,  
      trackTime: true,
      approveOrRejectTimesheet: true,
      submitTimesheet: true
    },  
    projects: {
      viewActiveProjects: true,
      addProjects: true,
      editActiveProjects: true,
      deleteActiveProjects: true,
      viewClosedProjects: true,
      closureOfProject: true,
      reopenClosedProjects: true,
      viewTeam: true,
      addTeam: true,
      editTeam: true,
      deleteTeam: true,
      requestResources: true,
      approveRejectRequestsForResources: true,
      requestExtension: true,
      approveRejectExtensionRequests: true,
      viewMilestone: true,
      addMilestone: true,
      editMilestone: true,
      deleteMilestone: true,
      viewSkillset: true,
      addSkillset: true,
      deleteSkillset: true,
      viewCRFR: true,
      addCRFR: true,
      editCRFR: true,
      deleteCRFR: true,
      viewAllHistory: true,
      viewAllocationHistory: true,
      viewExtensionHistory: true
    },
    team: {
      viewTeamListing: false,
      addNewTeamMember: false,
      editTeam: false,
      deleteTeam: false
    },
    skillset: {
      viewSkillsetListing: false,
      addNewSkillset: false,
      deleteSkillset: false,
      editSkillset: false
    },
    rolesAndAccess: {
      setAccessForDifferentRoles: false
    }
  },
  {
    role: 'Resource Manager',
    board: {
      activeProjects: true,
      team: true,
      resourcesOnBench: true,
      requestForResources: true,
      requestForResourcesAllocate: true,
      requestForExtensionApproveReject: true,
      myActions: true,
      alerts: true
    },
    timesheet: {
      viewTimesheet: true,
      addTimeEntry: true,
      editTrackedOrEnteredTime: true,
      deleteTimesheet: true,  
      trackTime: true,
      approveOrRejectTimesheet: true,
      submitTimesheet: true
    },  
    projects: {
      projectsListingActive: true,
      addProjects: true,
      editProjects: true,
      deleteProjects: true,
      projectsListingClosed: true,
      closeOfProject: true,
      reopenClosedProjects: true,
      viewTeam: true,
      addTeam: true,
      editTeam: true,
      deleteTeam: true,
      requestForAdditionalResources: true,
      requestForResourceApproveReject: true,
      requestForExtension: true,
      requestForExtensionApproveReject: true,
      viewMilestone: true,
      addMilestone: true,
      editMilestone: true,
      deleteMilestone: true,
      viewSkillset: true,
      addSkillset: true,
      deleteSkillset: true,
      viewCRFR: true,
      addCRFR: true,
      editCRFR: true,
      deleteCRFR: true,
      historyViewAll: true,
      historyViewAllocation: true,
      historyViewExtension: true
    },
    team: {
      viewTeamListing: true,
      addNewTeamMember: true,
      editTeam: true,
      deleteTeam: true
    },
    skillset: {
      viewSkillsetListing: true,
      addNewSkillset: true,
      deleteSkillset: true,
      editSkillset: true
    },
    rolesAndAccess: {
      setAccessForDifferentRoles: false
    }
  },
  {
    role: 'Employee',
    board: {
      activeProjects: false,
      team: false,
      resourcesOnBench: false,
      requestForResources: false,
      requestForResourcesAllocate: false,
      requestForExtensionApproveReject: false,
      myActions: true,
      alerts: true
    },
    timesheet: {
      viewTimesheet: true,
      addTimeEntry: true,
      editTrackedOrEnteredTime: true,
      deleteTimesheet: true,  
      trackTime: true,
      approveOrRejectTimesheet: true,
      submitTimesheet: true
    },  
    projects: {
      projectsListingActive: true,
      addProjects: true,
      editProjects: false,
      deleteProjects: false,
      projectsListingClosed: false,
      closeOfProject: false,
      reopenClosedProjects: false,
      viewTeam: false,
      addTeam: false,
      editTeam: false,
      deleteTeam: false,
      requestForAdditionalResources: false,
      requestForResourceApproveReject: false,
      requestForExtension: false,
      requestForExtensionApproveReject: false,
      viewMilestone: false,
      addMilestone: false,
      editMilestone: false,
      deleteMilestone: false,
      viewSkillset: false,
      addSkillset: false,
      deleteSkillset: false,
      viewCRFR: false,
      addCRFR: false,
      editCRFR: false,
      deleteCRFR: false,
      historyViewAll: false,
      historyViewAllocation: false,
      historyViewExtension: false
    },
    team: {
      viewTeamListing: false,
      addNewTeamMember: false,
      editTeam: false,
      deleteTeam: false
    },
    skillset: {
      viewSkillsetListing: false,
      addNewSkillset: false,
      deleteSkillset: false,
      editSkillset: false
    },
    rolesAndAccess: {
      setAccessForDifferentRoles: false
    }
  },
  // {
  //   role: 'HR',
  //   board: {
  //     activeProjects: false,
  //     team: false,
  //     resourcesOnBench: false,
  //     requestForResources: false,
  //     requestForResourcesAllocate: false,
  //     requestForExtensionApproveReject: false,
  //     myActions: true,
  //     alerts: true
  //   },
  //   timesheet: {
  //     viewTimesheet: true,
  //     addTimeEntry: true,
  //     editTrackedOrEnteredTime: true,
  //     deleteTimesheet: true,  
  //     trackTime: true,
  //     approveOrRejectTimesheet: true,
  //     submitTimesheet: true
  //   }, 
  //   projects: {
  //     projectsListingActive: true,
  //     projectsListingClosed: true,
  //     reopenClosedProjects: false,
  //     addProjects: false,
  //     addTeam: false,
  //     editTeam: false,
  //     viewTeam: false,
  //     requestForAdditionalResources: true,
  //     approveRequestsForResources: false,
  //     rejectRequestForResources: false,
  //     requestForExtension: false,
  //     requestForExtensionApproveReject: false,
  //     addMilestone: true,
  //     editMilestone: true,
  //     viewMilestone: true,
  //     deleteMilestone: true,
  //     viewSkillset: true,
  //     addSkillset: false,
  //     removeSkillset: false,
  //     deleteSkillset: false,
  //     addCRFR: false,
  //     viewCRFR: true,
  //     editCRFR: true,
  //     deleteCRFR: true,
  //     historyViewAll: true,
  //     historyViewAllocation: true,
  //     historyViewExtension: true
  //   },
  //   team: {
  //     viewTeamListing: false,
  //     addNewTeamMember: false,
  //     editTeam: false,
  //     deleteTeam: true
  //   },
  //   skillset: {
  //     viewSkillsetListing: false,
  //     addNewSkillset: false,
  //     deleteSkillset: false,
  //     editSkillset: false
  //   },
  //   rolesAndAccess: {
  //     setAccessForDifferentRoles: false
  //   }
  // },
  // {
  //   role: 'Sales',
  //   board: {
  //     activeProjects: false,
  //     team: false,
  //     resourcesOnBench: false,
  //     requestForResources: false,
  //     requestForResourcesAllocate: false,
  //     requestForExtensionApproveReject: false,
  //     myActions: true,
  //     alerts: true
  //   },
  //   timesheet: {
  //     trackTime: true,
  //     editTrackedOrEnteredTime: true,
  //     addTimeEntry: true,
  //     submitTimesheet: true,
  //     approveOrRejectTimesheet: true,
  //     viewTimesheet : true
  //   },
  //   projects: {
  //     projectsListingActive: true,
  //     projectsListingClosed: true,
  //     reopenClosedProjects: false,
  //     addProjects: false,
  //     addTeam: false,
  //     editTeam: false,
  //     viewTeam: false,
  //     requestForAdditionalResources: true,
  //     approveRequestsForResources: false,
  //     rejectRequestForResources: false,
  //     requestForExtension: false,
  //     requestForExtensionApproveReject: false,
  //     addMilestone: true,
  //     editMilestone: true,
  //     viewMilestone: true,
  //     deleteMilestone: true,
  //     viewSkillset: true,
  //     addSkillset: false,
  //     removeSkillset: false,
  //     deleteSkillset: false,
  //     addCRFR: false,
  //     viewCRFR: true,
  //     editCRFR: true,
  //     deleteCRFR: true,
  //     historyViewAll: true,
  //     historyViewAllocation: true,
  //     historyViewExtension: true
  //   },
  //   team: {
  //     viewTeamListing: false,
  //     addNewTeamMember: false,
  //     editTeam: false,
  //     deleteTeam: true
  //   },
  //   skillset: {
  //     viewSkillsetListing: false,
  //     addNewSkillset: false,
  //     deleteSkillset: false,
  //     editSkillset: false
  //   },
  //   rolesAndAccess: {
  //     setAccessForDifferentRoles: false
  //   }
  // },
];

// Function to seed Access data
const seedAccess = async () => {
  try {
    // Remove existing data (optional)
    await Access.deleteMany({});

    // Create and save new Access documents
    await Access.insertMany(accessData);

    console.log('Access data seeded successfully');
    db.close();
  } catch (error) {
    console.error('Error seeding Access data:', error);
    db.close();
  }
};

// Call the seedAccess function to start seeding
seedAccess();