const mongoose = require('mongoose');
const bcrypt = require('bcrypt');
const Employee = require('../models/employeeSchema');
const Role = require('../models/roleSchema');
const Skillset = require('../models/skillset');

require('dotenv').config({ path: '../../.env' });

mongoose.connect(process.env.MONGODB_URI);

const db = mongoose.connection;
db.on('error', console.error.bind(console, 'MongoDB connection error:'));

const seedSuperAdmin = async () => {
  try {
    // Remove existing employee data
    await Employee.deleteMany({});

    // Find the SuperAdmin role
    const superAdminRole = await Role.findOne({ roleName: 'Super Admin' });

    if (!superAdminRole) {
      throw new Error('SuperAdmin role not found. Please run the Role seeder first.');
    }

    // Hash the password
    const salt = await bcrypt.genSalt(10);
    const hashedPassword = await bcrypt.hash('ronysebastian@softnotions', salt);

    const skillsets = await Skillset.find({ name: { $in: ['Leadership', 'Strategic Planning'] } });

    if (skillsets.length === 0) {
      throw new Error('Required skillsets not found. Please run the Skillset seeder first.');
    }

    const superAdminData = {
      name: 'Rony Sebastian',
      email: 'ronysebastian@softnotions.com',
      password: hashedPassword,
      employeeId: 'SA001',
      type: 'Full-time',
      designation: 'Super Administrator',
      skillset: skillsets.map(skill => skill._id),
      status: 'Active',
      billableStatus: 'Non-Billable',
      dateOfJoining: new Date().toISOString(),
      role: superAdminRole._id,
      mustChangePassword: true,
      visibility: true,
    };

    // Create and save the Super Admin
    const superAdmin = new Employee(superAdminData);
    await superAdmin.save();

    console.log('Super Admin seeded successfully');
  } catch (error) {
    console.error('Error seeding Super Admin:', error);
  } finally {
    await db.close();
  }
};

// Call the seedSuperAdmin function to start seeding
seedSuperAdmin();