const mongoose = require('mongoose');
const Role = require('../models/roleSchema');
const Access = require('../models/accessSchema');

require('dotenv').config({ path: '../../.env' });

// Connect to MongoDB
console.log('s', process.env.MONGODB_URI);
mongoose.connect(process.env.MONGODB_URI);

const db = mongoose.connection;
db.on('error', console.error.bind(console, 'MongoDB connection error:'));

const seedRoles = async () => {
  try {
    // Remove existing role data
    await Role.deleteMany({});

    // Fetch all Access documents
    const allAccesses = await Access.find();
    console.log('Found Access documents:', allAccesses.length);

    if (allAccesses.length === 0) {
      throw new Error('No Access documents found. Please run the Access seeder first.');
    }

    // Use the first four Access documents for the roles
    // HrAccess, SalesAccess
    const [superAdminAccess, employeeAccess, resourceManagerAccess, tamAccess] = allAccesses.slice(0, 6);

    const roleData = [
      {
        roleName: 'Super Admin',
        access: superAdminAccess._id,
        routes: [true, true, true, true, true, true, true]
      },
      {
        roleName: 'Employee',
        access: employeeAccess._id,
        routes: [true, true, false, false, false, false, false]
      },
      {
        roleName: 'Resource Manager',
        access: resourceManagerAccess._id,
        routes: [true, true, true, true, true, true, false]
      },
      {
        roleName: 'TAM',
        access: tamAccess._id,
        routes: [true, true, true, true, true, false, false]
      },
      // {
      //   roleName: 'HR',
      //   access: HrAccess._id,
      //   routes: [true, true, true, true, true, false, false]
      // },
      // {
      //   roleName: 'Sales',
      //   access: SalesAccess._id,
      //   routes: [true, true, true, true, true, false, false]
      // }
    ];

    // Create and save new Role documents
    await Role.insertMany(roleData);

    console.log('Role data seeded successfully');
  } catch (error) {
    console.error('Error seeding Role data:', error);
  } finally {
    await db.close();
  }
};

// Call the seedRoles function to start seeding
seedRoles();