const mongoose = require('mongoose');
const Skillset = require('../models/skillset'); 
require('dotenv').config({ path: '../../.env' });

mongoose.connect(process.env.MONGODB_URI);

const db = mongoose.connection;
db.on('error', console.error.bind(console, 'MongoDB connection error:'));

const seedSkillsets = async () => {
  try {
    // Remove existing skillset data
    await Skillset.deleteMany({});

    // Array of skillsets to be seeded
    const skillsets = [
      { name: 'Leadership', category: 'Management' },
      { name: 'Strategic Planning', category: 'Management' },
      { name: 'Financial Acumen', category: 'Finance' },
      { name: 'Decision Making', category: 'Management' },
      { name: 'Corporate Governance', category: 'Business' }
    ];

    // Sort skillsets alphabetically by name
    skillsets.sort((a, b) => a.name.localeCompare(b.name));

    // Insert sorted skillsets into the database
    await Skillset.insertMany(skillsets);

    console.log('Skillsets seeded successfully in alphabetical order');
  } catch (error) {
    console.error('Error seeding skillsets:', error);
  } finally {
    await db.close();
  }
};

// Call the seedSkillsets function to start seeding
seedSkillsets();