const mongoose = require('mongoose');

const crfrSchema = new mongoose.Schema({
  crfrId: {
    type: String,
    required: true,
  },
  approvedOn: {
    type: Date,
    required: true,
  },
  startDate: {
    type: Date,
    required: true,
  },
  status: {
    type: String,
    required: true,
  },
  closureDate: {
    type: Date,
  },
  sowFile: {
    type: String, // Path to the file
  },
  visibility: {
    type: Boolean,
    default: true,
  },
  projectID: {
    type: mongoose.Schema.Types.ObjectId,
    ref: 'Project',
    required: true,
  },
}, { timestamps: true });

// Remove all existing indexes
crfrSchema.indexes().forEach(index => crfrSchema.index(index[0], { unique: false }));

// Add the compound unique index
crfrSchema.index({ crfrId: 1, projectID: 1 }, { unique: true });

const CRFR = mongoose.model('CRFR', crfrSchema);

// Function to ensure indexes
const ensureIndexes = async () => {
  try {
    await CRFR.collection.dropIndexes();
    await CRFR.createIndexes();
  } catch (error) {
    console.error('Error recreating CRFR indexes:', error);
  }
};

// Call this function when your application starts
ensureIndexes();

module.exports = CRFR;