const jwt = require('jsonwebtoken');
const config = require('../config/config');
const Employee = require('../database/models/employeeSchema');

const authMiddleware = async (req, res, next) => {
  const token = req.header('Authorization')?.replace('Bearer ', '');
  if (!token) return res.status(401).send({ message: 'Access denied. No token provided.' });

  try {
    const decoded = jwt.verify(token, config.ACCESS_TOKEN_SECRET);
    req.user = await Employee.findById(decoded._id);
    if (!req.user) throw new Error('User not found');
    next();
  } catch (ex) {
    if (ex.name === 'TokenExpiredError') {
      return res.status(401).send({ message: 'Token expired', expired: true });
    }
    res.status(401).send({ message: 'Invalid token' });
  }
};

module.exports = authMiddleware;