const authService = require('./Services/auth.service');
const Employee = require('../../database/models/employeeSchema');

const Token = require('../../database/models/token');
const sendEmail = require('../../utils/sendEmail');
const Joi = require('joi');
const crypto = require('crypto');
const TokenExpiredError = require('../../database/models/token');
const bcrypt = require('bcrypt');
//const jwt = require('jsonwebtoken');
const config = require('../../config/config');

 
const login = async (req, res) => {
  try {
    const { email, password } = req.body;
    const result = await authService.loginUser(email, password);
    res.status(200).json(result);
  } catch (error) {
    console.error('Login error:', error);
    
    if (error.message === 'Your account is currently inactive.') {
      return res.status(403).json({ error: error.message });
    } else if (error.message === 'Invalid email or password') {
      return res.status(401).json({ error: error.message });
    } else {
      return res.status(500).json({ error: 'An unexpected error occurred. Please try again later.' });
    }
  }
};

const refreshToken = async (req, res) => {
  try {
    const { refreshToken } = req.body;
    const newTokens = await authService.refreshAuthToken(refreshToken);
    res.status(200).json(newTokens);
  } catch (error) {
    console.error('Token refresh error:', error);
    res.status(401).json({ error: error.message });
  }
};

const logout = async (req, res) => {
  try {
    const userId = req.user._id;
    await authService.logoutUser(userId);
    res.status(200).json({ message: 'Successfully logged out' });
  } catch (error) {
    console.error('Logout error:', error);
    res.status(500).json({ error: 'Logout failed' });
  }
};


const forgotpassword = async (req, res) => {
  try {
    const schema = Joi.object({ email: Joi.string().email().required() });
    const { error } = schema.validate(req.body);
    if (error) {
      console.log('Validation Error:', error.details[0].message);
      return res.status(400).send(error.details[0].message);
    }

    const user = await Employee.findOne({ email: req.body.email });
    if (!user) {
      console.log('User not found:', req.body.email);
      return res.status(400).send('User with the given email does not exist');
    }

    let token = await TokenExpiredError.findOne({ userId: user._id });
    if (!token) {
      console.log('Creating new token for user:', user._id);
      token = await new TokenExpiredError({
        userId: user._id,
        token: crypto.randomBytes(32).toString('hex'),
      }).save();
    }
        
    const link = `${process.env.BASE_URL}/password-reset/${user._id}/${token.token}`;
    const formlink = `${process.env.FORM_URL}/${user._id}/${token.token}`;
    console.log('Password reset link:', formlink);
    console.log('Password reset backend token', link);
        

    await sendEmail(user.email, 'Password Reset', formlink);
    console.log('Email sent to:', user.email);

    res.send('Password reset link sent to your email account');
  } catch (error) {
    console.error('An error occurred:', error);
    res.status(500).send('An error occurred');
  }
};




const passwordreset = async (req, res) => {
  try {
      
    const schema = Joi.object({password: Joi.string().required()});
    const{error} = schema.validate(req.body);
    if(error) return res.status(400).send(error.details[0].message);

    const user = await Employee.findById(req.params.id);
    if(!user) return res.status(400).send('Invalid link or expired.');
        
    const token = await Token.findOne({
      userId:user._id,
      token:req.params.token
    });
        
    if(!token) return res.status(400).send('invalid link or expired');
        
    const saltRounds = Number(config.SALT) || 10;
    const salt = await bcrypt.genSalt(saltRounds);
    const hashedPassword = await bcrypt.hash(req.body.password, salt);

         
    user.password = hashedPassword; ///req.body.password
    await user.save();
    await token.deleteOne();

    res.send('password reset successfully');
    
  } catch (error) {

    res.send('An error occured');
    console.log(error);
     
  }
};


module.exports = {
  login,
  refreshToken,
  logout,
  passwordreset,
  forgotpassword

};