// profile.router.js
const express = require('express');
const router = express.Router();
const profileController = require('./profile.controller');
const multer = require('multer');
const path = require('path');
const authMiddleware = require('../../middlewares/authMiddleware');
// Configure Multer for file uploads
const storage = multer.diskStorage({
  destination: (req, file, cb) => {
    cb(null, path.join(__dirname, '../../uploads/images'));
  },
  filename: (req, file, cb) => {
    cb(null, `${req.query.id}-${Date.now()}${path.extname(file.originalname)}`);
  }
});

const upload = multer({ storage: storage });

router.get('/',authMiddleware, profileController.getProfile);
router.patch('/reset-password',authMiddleware, (req, res, next) => {
  next();
}, profileController.resetPassword); 
router.get('/picture',authMiddleware, profileController.getProfilePicture);
router.post('/upload',authMiddleware,(req,res, next) =>{
  next();
}, upload.single('profilePicture'), profileController.uploadProfilePicture);
router.delete('/delete-picture',authMiddleware, profileController.deleteProfilePicture);
router.patch('/reset-password-new', profileController.resetPasswordNew);


module.exports = router;
