/* eslint-disable no-useless-catch */
const roleRepository = require('../role.repository');
const accessRepository = require('../role.repository');
const employeeRepository = require('../role.repository');



const addRole = async (roleData) => {
  try {
    return await roleRepository.createRole(roleData);
  } catch (error) {
    throw new Error('Error creating role: ' + error.message);
  }
};

const getAllRoles = async () => {
  try {
    return await roleRepository.findAllRoles();
  } catch (error) {
    throw error;
  }
};

const createAccess = async (data) => {
  try {
    return await accessRepository.createAccess(data);
  } catch (error) {
    throw error;
  }
};

const mergeAccess = (baseAccess, tamAccess) => {
  const mergedAccess = JSON.parse(JSON.stringify(baseAccess)); // Deep clone

  for (const category in tamAccess) {
    if (!mergedAccess[category]) {
      mergedAccess[category] = {};
    }
    for (const permission in tamAccess[category]) {
      mergedAccess[category][permission] = 
        mergedAccess[category][permission] || tamAccess[category][permission];
    }
  }

  return mergedAccess;
};

const tamAccess = {
  board: {
    activeProjects: false,
    team: false,
    resourcesOnBench: false,
    requestForResources: false,
    requestForResourcesAllocate: false,
    requestForExtensionApproveReject: false,
    myActions: true,
    alerts: true
  },
  timesheet: {
    viewTimesheet: true,
    addTimeEntry: true,
    editTrackedOrEnteredTime: true,
    deleteTimesheet: true,  
    trackTime: true,
    approveOrRejectTimesheet: true,
    submitTimesheet: true
  },  
  projects: {
    viewActiveProjects: true,
    addProjects: true,
    editActiveProjects: true,
    deleteActiveProjects: true,
    viewClosedProjects: true,
    closureOfProject: true,
    reopenClosedProjects: true,
    viewTeam: true,
    addTeam: true,
    editTeam: true,
    deleteTeam: true,
    requestResources: true,
    approveRejectRequestsForResources: true,
    requestExtension: true,
    approveRejectExtensionRequests: true,
    viewMilestone: true,
    addMilestone: true,
    editMilestone: true,
    deleteMilestone: true,
    viewSkillset: true,
    addSkillset: true,
    deleteSkillset: true,
    viewCRFR: true,
    addCRFR: true,
    editCRFR: true,
    deleteCRFR: true,
    viewAllHistory: true,
    viewAllocationHistory: true,
    viewExtensionHistory: true
  },
  team: {
    viewTeamListing: true,
    addNewTeamMember: true,
    editTeam: true
  },
  report: {
    employeeTimesheetReport: true,
    estimatedVsActualReport: true
  },
  skillset: {
    viewSkillsetListing: false,
    addNewSkillset: false,
    deleteSkillset: false,
    editSkillset: false
  },
  rolesAndAccess: {
    setAccessForDifferentRoles: false
  }
};

const tamRoutes = [true, true, false, true, true, false, false];


const getEmployeeDetails = async (employeeId) => {
  try {
    const employee = await employeeRepository.findEmployeeById(employeeId)
      .populate({
        path: 'role',
        populate: {
          path: 'access'
        }
      });

    if (!employee) {
      throw new Error('Employee not found');
    }

    // Check if the employee's role is superAdmin or ResourceManager
    if (employee.role.roleName === 'Super Admin' || employee.role.roleName === 'Resource Manager') {
      console.log(`Employee ${employeeId} has role ${employee.role.roleName}. No modifications applied.`);
      return employee.toObject();
    }

    // For all other roles, proceed with the existing logic
    let roleData = {
      access: { ...employee.role.access.toObject() },
      routes: [...employee.role.routes]
    };

    if (employee.TAMofProjects && employee.TAMofProjects.length > 0) {
      console.log(`Employee ${employeeId} has ${employee.TAMofProjects.length} TAMofProjects`);
      
      // Merge access rights
      roleData.access = mergeAccess(roleData.access, tamAccess);

      // Merge routes
      roleData.routes = roleData.routes.map((route, index) => route || tamRoutes[index]);
    } 
    // else {
    //   console.log(`Employee ${employeeId} has no TAMofProjects`);
    // }

    // Return the employee data with the potentially merged role data
    return {
      ...employee.toObject(),
      role: {
        ...employee.role.toObject(),
        access: roleData.access,
        routes: roleData.routes
      }
    };

  } catch (error) {
    console.error('Error in getEmployeeDetails:', error);
    throw new Error('Error fetching employee details: ' + error.message);
  }
};

const updateRoleAccess = async (roleId, updateData) => { 
  try {
    const role = await roleRepository.findRoleById(roleId);
    if (!role) {
      throw new Error('Role not found');
    }

    const access = await accessRepository.findAccessById(role.access);
    if (!access) {
      throw new Error('Access not found');
    }

    // Update the access permissions
    for (let key in updateData) {
      if (access[key] !== undefined) {
        access[key] = updateData[key];
      }
    }

    // Update the routes (assuming updateData.routes is an array)
    if (Array.isArray(updateData.routes)) {
      role.routes = updateData.routes;
    }

    await access.save();
    await role.save();

    return role;
  } catch (error) {
    console.error('Error updating access:', error);
    throw new Error('Error updating access: ' + error.message);
  }
};

const getRoleDetails = async (roleId) => {
  try {
    const roleDetails = await roleRepository.findRoleById(roleId);
    return roleDetails;
  } catch (error) {
    throw new Error('Error fetching role details: ' + error.message);
  }
};

const updateRoleAccessAndRoutes = async (roleId) => {
  try {
    const role = await roleRepository.findRoleById(roleId);
    if (!role) {
      throw new Error('Role not found');
    }
    // Update access
    const updatedAccess = { ...role.access };
    for (const category in tamAccess) {
      if (!updatedAccess[category]) {
        updatedAccess[category] = {};
      }
      for (const permission in tamAccess[category]) {
        if (updatedAccess[category][permission] === undefined || !updatedAccess[category][permission]) {
          updatedAccess[category][permission] = tamAccess[category][permission];
        }
      }
    }

    // Update routes
    const updatedRoutes = role.routes.map((route, index) => route || tamRoutes[index]);

    const updatedRole = await roleRepository.updateRoleAndAccess(roleId, updatedAccess, updatedRoutes);
    return updatedRole;
  } catch (error) {
    console.error('Error updating role access and routes:', error);
    throw new Error('Error updating role access and routes: ' + error.message);
  }
};

module.exports = {
  addRole,
  createAccess,
  getAllRoles,
  getEmployeeDetails,
  updateRoleAccess ,
  getRoleDetails,
  updateRoleAccessAndRoutes
};
