/* eslint-disable no-useless-catch */
const Role = require('../../database/models/roleSchema');
const Access = require('../../database/models/accessSchema');
const Employee = require('../../database/models/employeeSchema');


const createRole = (roleData) => {
  const role = new Role(roleData);
  return role.save();
};

//To get all the roles  
const findAllRoles = async () => {
  try {
    return await Role.find();
  } catch (error) {
    throw error;
  }
};

const createAccess = async (data) => {
  try {
    const access = new Access(data);
    return await access.save();
  } catch (error) {
    throw error;
  }
};

const findEmployeeById = (employeeId) => {
  try {
    return Employee.findById(employeeId); // Return a Mongoose query object
  } catch (error) {
    throw error;
  }
};

const findRoleById = async (roleId) => {
  try {
    return await Role.findById(roleId).populate('access');
  } catch (error) {
    console.error('Error in findRoleById:', error);
    throw new Error('Error finding role by ID: ' + error.message);
  }
};

const findAccessById = async (accessId) => {
  try {
    return await Access.findById(accessId);
  } catch (error) {
    console.error('Error in findAccessById:', error);
    throw new Error('Error finding access by ID: ' + error.message);
  }
};

const updateRoleAndAccess = async (roleId, updatedAccess, updatedRoutes) => {
  try {
    const role = await Role.findById(roleId).populate('access');
    if (!role) {
      throw new Error('Role not found');
    }

    // Update access
    Object.assign(role.access, updatedAccess);
    await role.access.save();

    // Update routes
    role.routes = updatedRoutes;
    await role.save();

    return role;
  } catch (error) {
    console.error('Error in updateRoleAndAccess:', error);
    throw new Error('Error updating role and access: ' + error.message);
  }
};



module.exports = {
  createRole,
  createAccess,
  findAllRoles,
  findEmployeeById,
  findRoleById,
  findAccessById,
  updateRoleAndAccess
};