const Skillset = require('../../database/models/skillset'); // Adjust the path to your Skillset model
const applySearchAndPagination = require('../../utils/paginationAndSearch');

const findById = async (id) => {
  return await Skillset.findById(id).select('name category');
};
const findAllWithSearchAndPagination = async (search, page, limit) => {
  const searchFields = ['name', 'category'];
  return await applySearchAndPagination(Skillset, searchFields, search, page, limit);
};

const findAll = async () => {
  return await Skillset.find();
};

const create = async (skillsetData) => {
  const newSkillset = new Skillset(skillsetData);
  try {
    return await newSkillset.save();
  } catch (error) {
    if (error.code === 11000) { // Duplicate key error
      console.error('Duplicate skillset error:', error);
      throw new Error('Skillset with this name already exists:',error);
    }
    console.error('Error saving skillset:', error);
    throw new Error('An error occurred while saving the skillset.');
  }
};


const updateById = async (id, skillsetData) => {
  return await Skillset.findByIdAndUpdate(id, skillsetData, { new: true });
};

const deleteById = async (id) => {
  return await Skillset.findByIdAndDelete(id);
};

module.exports = {
  findAll,
  create,
  updateById,
  deleteById,
  findAllWithSearchAndPagination,
  findById

};
