const express = require('express');
const router = express.Router();
const timesheetController = require('./timesheet.controller');
const authMiddleware = require('../../middlewares/authMiddleware');

// Route to add a time entry
router.post('/add', authMiddleware, timesheetController.addTimeEntry);

// Route to get total hours worked in a specific month
router.get('/monthly-hours', authMiddleware, timesheetController.getMonthlyHours);

router.get('/daily-entries/:employeeid/:timesheetdate', authMiddleware, timesheetController.getDailyEntries);

// Route to delete a specific time entry log
router.delete('/daily-entries/:employeeid/:timesheetdate/:timeentryId', authMiddleware, timesheetController.deleteTimeEntry);
router.patch('/daily-entries/:employeeid/:timesheetdate/:timeentryId', authMiddleware, timesheetController.updateTimeEntry);
router.patch('/submit/:timesheetId', authMiddleware, timesheetController.submitTimesheet);
router.patch('/approve/:timesheetId', authMiddleware, timesheetController.approveTimeEntries);
router.patch('/reject/:timesheetId', authMiddleware, timesheetController.rejectTimeEntries);
router.get('/entries/:timesheetId', authMiddleware, timesheetController.getTimesheetEntries);
router.get('/tam/:tamId', authMiddleware, timesheetController.getTamTimesheets);
router.get('/histories/:employeeId', authMiddleware, timesheetController.getTimeEntryHistories);
router.post('/notifications/read/:employeeId', authMiddleware, timesheetController.markNotificationsAsRead);
router.get('/notifications/unread-count/:employeeId', authMiddleware, timesheetController.getUnreadNotificationCount);
router.patch('/timer/start',authMiddleware,timesheetController.startTimer);
router.patch('/timer/stop',authMiddleware,timesheetController.stopTimer);
router.get('/employees_categories_hours',authMiddleware,timesheetController.getWorkedHours);
router.patch('/approve-all', authMiddleware, timesheetController.approveProjectEntries);
router.get('/pending-approvals/:tamId',authMiddleware,timesheetController.getPendingApprovals);

module.exports = router;
