const extensionService = require('./service/extension.service');

const createExtensionRequest = async (req, res) => {
  try {
    const { userRole, ...extensionData } = req.body;
    const extension = await extensionService.createExtensionRequest(extensionData, userRole);
    res.status(201).json(extension);
  } catch (error) {
    console.error('Error creating extension request:', error);
    res.status(400).json({ message: error.message });
  }
};


const getPendingExtensions = async (req, res) => {
  try {
    const { search, page = 1, limit = 25, fetchAll = false } = req.query;
    const result = await extensionService.getPendingExtensions(search, page, limit, fetchAll === 'true');
    res.status(200).json(result);
  } catch (error) {
    console.error('Error getting pending extensions:', error);
    res.status(500).json({ message: 'Internal server error' });
  }
};

const updateExtensionStatus = async (req, res) => {
  try {
    const { id } = req.params;
    const { status, userRole } = req.body;
    const updatedExtension = await extensionService.updateExtensionStatus(id, status, userRole);
    res.status(200).json(updatedExtension);
  } catch (error) {
    console.error('Error updating extension status:', error);
    res.status(400).json({ message: error.message });
  }
};


const getExtensionHistoryByProjectId = async (req, res) => {
  try {
    const { projectId } = req.params;
    if (!projectId) {
      return res.status(400).json({ message: 'Project ID is required' });
    }
    const history = await extensionService.getExtensionHistoryByProjectId(projectId);
    res.status(200).json(history);
  } catch (error) {
    console.error('Error getting extension history by project ID:', error);
    if (error.message === 'Invalid project ID') {
      res.status(400).json({ message: 'Invalid project ID' });
    } else {
      res.status(500).json({ message: 'Internal server error' });
    }
  }
};

const getPendingExtensionsByProjectId = async (req, res) => {
  try {
    const { projectId } = req.params; 
    if (!projectId) {
      return res.status(400).json({ message: 'Project ID is required' });
    }
    const pendingExtensions = await extensionService.getPendingExtensionsByProjectId(projectId);
    res.status(200).json(pendingExtensions);
  } catch (error) {
    console.error('Error getting pending extensions by project ID:', error);
    if (error.message === 'Invalid project ID') {
      res.status(400).json({ message: 'Invalid project ID' });
    } else {
      res.status(500).json({ message: 'Internal server error' });
    }
  }
};

module.exports = {
  createExtensionRequest,
  getPendingExtensions,
  updateExtensionStatus,
  getExtensionHistoryByProjectId,
  getPendingExtensionsByProjectId
};