const teamMemberRepository = require('../projectTeamMember.repository');
const Employee = require('../../../../database/models/employeeSchema');
const ProjectTeamMember = require('../../../../database/models/project/projectTeamMemberSchema');
const Project = require('../../../../database/models/project/projectSchema');


const getProjectTeamMembers = async () => {
  return await teamMemberRepository.findAll();
};

const getProjectTeamMemberById = async (id) => {
  return await teamMemberRepository.findById(id);
};

const getProjectTeamMembersByProjectId = async (projectId, search, page, limit) => {
  return await teamMemberRepository.findByProjectId(projectId, search, page, limit);
};

const addProjectTeamMember = async (teamMemberData) => {
  return await teamMemberRepository.createMany(teamMemberData);
};

const editProjectTeamMember = async (id, teamMemberData) => {
  if (teamMemberData.length === 1) {
    // Single team member edit
    return await teamMemberRepository.updateById(id, teamMemberData[0]);
  } else {
    // Multiple team members edit
    const updatedMembers = await Promise.all(
      teamMemberData.map(async (member) => {
        if (member._id) {
          return await teamMemberRepository.updateById(member._id, member);
        } else {
          throw new Error('Each team member must have an _id for bulk update');
        }
      })
    );
    return updatedMembers;
  }
};


const deleteProjectTeamMember = async (id) => {
  // Find the project team member
  const projectTeamMember = await ProjectTeamMember.findById(id);
  if (!projectTeamMember) {
    throw new Error('Team member not found');
  }

  const employeeId = projectTeamMember.employee;
  const projectId = projectTeamMember.project;

  // Find the employee
  const employee = await Employee.findById(employeeId);
  if (!employee) {
    throw new Error('Employee not found');
  }

  // Find the project
  const project = await Project.findById(projectId);
  if (!project) {
    throw new Error('Project not found');
  }

  // Remove the project from TAMofProjects if it exists
  employee.TAMofProjects = employee.TAMofProjects.filter(
    (tamProject) => !tamProject.equals(projectId)
  );

  // Update the employee's Projects array
  const projectIndex = employee.Projects.findIndex(
    (proj) => proj.projectId.equals(projectId)
  );
  if (projectIndex !== -1) {
    employee.Projects[projectIndex].active = false;
  }

  // Remove TAM from the project if it matches the employee
  if (project.tam && project.tam.equals(employeeId)) {
    project.tam = null;
    await project.save();
  }

  // Save the updated employee document
  await employee.save();

  // Soft delete the project team member
  projectTeamMember.visibility = false;
  await projectTeamMember.save();

  return projectTeamMember;
};


module.exports = {
  getProjectTeamMembers,
  getProjectTeamMemberById,
  getProjectTeamMembersByProjectId,
  addProjectTeamMember,
  editProjectTeamMember,
  deleteProjectTeamMember
};
