const crfrService = require('../Projectcrfr/Services/Projectcrfr.service');
const path = require('path');
const fs = require('fs');

const getCRFRById = async (req, res) => {
  try {
    const projectId = req.params.id; // Project ID from URL
    const { search = '', page = 1, limit = 25 } = req.query; // Query parameters

    if (!projectId) {
      return res.status(400).send('Project ID is required');
    }

    const crfrs = await crfrService.getCRFRByProjectId(projectId, search, page, limit);
    if (!crfrs || crfrs.results.length === 0) {
      return res.status(404).send('No CR/FR entries found for this project');
    }

    res.json(crfrs);
  } catch (error) {
    console.error(error);
    res.status(500).send('Server error');
  }
};



// const createCRFR = async (req, res) => {
//   try {
//     const projectId = req.params.projectId;
//     const crfrData = {
//       crfrId: req.body.crfrId,
//       approvedOn: req.body.approvedOn,
//       startDate: req.body.startDate,
//       status: req.body.status,
//       closureDate: req.body.closureDate,
//       visibility: req.body.visibility,
//       projectID: projectId
//     };

//     if (req.file) {
//       // Store the relative path or a URL to the file
//       crfrData.sowFile = `/uploads/sowFiles/${req.file.filename}`;
//     }

//     const crfr = await crfrService.createCRFR(crfrData);
//     res.status(201).json(crfr);
//   } catch (error) {
//     if (error.code === 11000) {
//       res.status(400).json({ message: 'Duplicate key error', details: error.keyValue });
//     } else {
//       res.status(400).json({ message: 'Validation error', details: error.message });
//     }
//   }
// };


const createCRFR = async (req, res) => {
  try {
    const projectId = req.params.projectId;
    const crfrData = {
      crfrId: req.body.crfrId,
      approvedOn: req.body.approvedOn,
      startDate: req.body.startDate,
      status: req.body.status,
      closureDate: req.body.closureDate,
      visibility: req.body.visibility,
      projectID: projectId
    };

    if (req.file) {
      crfrData.sowFile = `/uploads/sowFiles/${req.file.filename}`;
    }

    const crfr = await crfrService.createCRFR(crfrData);
    res.status(201).json(crfr);
  } catch (error) {
    console.error('Error in createCRFR:', error);
    if (error.message === 'CRFR_EXISTS') {
      res.status(400).json({ 
        message: 'Duplicate CRFR', 
        details: 'A CRFR with this ID already exists for this project.'
      });
    } else {
      res.status(400).json({ message: 'Validation error', details: error.message });
    }
  }
};


const updateCRFR = async (req, res) => {
  try {
    const id = req.params.id;
    if (!id) {
      return res.status(400).send('ID is required');
    }

    const crfrData = { ...req.body };

    if (req.file) {
      crfrData.sowFile = `/uploads/sowFiles/${req.file.filename}`;
    }
    const updatedCRFR = await crfrService.updateCRFR(id, crfrData);
    res.json(updatedCRFR);
  } catch (error) {

    console.error('Error updating CRFR:', error);
    res.status(400).json({ message: 'Validation error', details: error });
    
  }
};



const deleteCRFR = async (req, res) => {
  try {
    const id = req.params.id;
    if (!id) {
      return res.status(400).send('ID is required');
    }
    const deletedCRFR = await crfrService.deleteCRFR(id);
    res.json({ message: 'CR/FR entry soft deleted', deletedCRFR });
  } catch (error) {
    console.error(error);
    res.status(500).send('Server error');
  }
};


const downloadFile = async (req, res) => {
  try {
    const CRFRId = req.params.id;
    if (!CRFRId) {
      return res.status(400).send('Milestone ID is required');
    }

    // Fetch the CRFR record associated with the milestone ID
    const crfr = await crfrService.getCRFRById(CRFRId);
    if (!crfr || !crfr.sowFile) {
      return res.status(404).send('File not found');
    }

    // The path stored in the database should be relative to the `uploads` directory
    const relativeFilePath = crfr.sowFile;
    // Construct the correct absolute file path without 'modules'
    const absoluteFilePath = path.resolve(__dirname, '../../../uploads/sowFiles/', path.basename(relativeFilePath));


    // Check if the file exists before sending
    if (!fs.existsSync(absoluteFilePath)) {
      console.error('File not found at path:', absoluteFilePath);
      return res.status(404).send('File not found');
    }

    // Send the file for download
    res.download(absoluteFilePath, path.basename(relativeFilePath), (err) => {
      if (err) {
        console.error('Error downloading file:', err);
        res.status(500).json({ message: 'Error downloading file', error: err.message });
      }
    });
  } catch (error) {
    console.error('Server error:', error);
    res.status(500).json({ message: 'Server error', error: error.message });
  }
};





module.exports = {
  getCRFRById,
  createCRFR,
  updateCRFR,
  deleteCRFR,
  downloadFile
};
