const CRFR = require('../../../database/models/project/crfrSchema');
const applySearchAndPagination = require('../../../utils/paginationAndSearch');

const findAllWithSearchAndPagination = async (search, page, limit) => {
  const searchFields = ['crfrId', 'status'];
  const populateFields = [];
  const baseQuery = { visibility: true };
  return await applySearchAndPagination(CRFR, searchFields, search, page, limit, populateFields, false, baseQuery);
};

const findByProjectId = async (projectId, search, page, limit) => {
  const searchFields = ['crfrId', 'status'];
  const populateFields = [];
  const baseQuery = { projectID: projectId, visibility: true };

  return await applySearchAndPagination(
    CRFR,
    searchFields,
    search,
    page,
    limit,
    populateFields,
    false,
    baseQuery
  );
};



const findById = async (id) => {
  return await CRFR.findOne({ _id: id, visibility: true });
};



const create = async (crfrData) => {
  try {
    

    // Check if a CR/FR with the same ID exists in the same project (including soft-deleted ones)
    const existingCrfr = await CRFR.findOne({ 
      crfrId: crfrData.crfrId,
      projectID: crfrData.projectID
    });

    if (existingCrfr) {
      if (existingCrfr.visibility === false) {
        // If it exists but is soft-deleted, update its visibility to true
        const updatedCrfr = await CRFR.findOneAndUpdate(
          { _id: existingCrfr._id },
          { visibility: true, ...crfrData },
          { new: true, runValidators: true }
        );
        return updatedCrfr;
      }
      // If it exists and is visible, throw a specific error
      throw new Error('CRFR_EXISTS');
    }

    // If no existing CR/FR in this project, create a new one
    const newCRFR = new CRFR(crfrData);
    return await newCRFR.save();
  } catch (error) {
    console.error('Error in create function:', error);
    if (error.code === 11000) {
      throw new Error('CRFR_EXISTS');
    }
    throw error; // Propagate other errors to be handled by calling code
  }
};




const updateById = async (id, crfrData) => {
  
  return await CRFR.findOneAndUpdate(
    { _id: id, visibility: true },
    crfrData,
    { new: true }
  );
};

const deleteById = async (id) => {
  return await CRFR.findByIdAndUpdate(id, { visibility: false }, { new: true });
};


module.exports = {
  findAllWithSearchAndPagination,
  findByProjectId,
  findById,
  create,
  updateById,
  deleteById,

};
