const express = require('express');
const router = express.Router();
const crfrController = require('./Projectcrfr.controller');
const multer = require('multer');
const path = require('path');
const authMiddleware = require('../../../middlewares/authMiddleware');
// Multer configuration for file storage
const storage = multer.diskStorage({
  destination: './uploads/sowFiles/',
  filename: function (req, file, cb) {
    cb(null, `${file.fieldname}-${Date.now()}${path.extname(file.originalname)}`);
  }
});

// Initialize upload middleware
const upload = multer({
  storage: storage,
  limits: { fileSize: 1000000 }, // 1MB limit
  fileFilter: function (req, file, cb) {
    const filetypes = /jpeg|jpg|png|pdf/;
    const extname = filetypes.test(path.extname(file.originalname).toLowerCase());
    const mimetype = filetypes.test(file.mimetype);
    mimetype && extname ? cb(null, true) : cb('Error: Invalid file type!');
  }
}).single('sowFile');

// CR/FR routes
router.get('/:id', authMiddleware, crfrController.getCRFRById);
router.post('/add/:projectId', authMiddleware, upload, crfrController.createCRFR);
router.patch('/:id', authMiddleware, upload, crfrController.updateCRFR);
router.delete('/:id', authMiddleware, crfrController.deleteCRFR);
router.get('/download/:id', authMiddleware, crfrController.downloadFile);



module.exports = router;
