const milestoneService = require('./Services/milestone.service');

const getMilestone = async (req, res) => {
  try {
    const { search, page = 1, limit = 25, projectId } = req.query;
    let milestones;
    
    if (projectId) {
      milestones = await milestoneService.getMilestonesByProjectId(projectId, search, page, limit);
    } else {
      milestones = await milestoneService.getMilestones(search, page, limit);
    }
    
    res.json(milestones);
  } catch (error) {
    console.error(error);
    res.status(500).send('Server error');
  }
};

const getMilestoneByID = async (req, res) => {
  try {
    const id = req.params.id;
    if (!id) {
      return res.status(400).send('ID is required');
    }

    const milestone = await milestoneService.getMilestoneById(id);
    if (!milestone) {
      return res.status(404).send('Milestone not found');
    }

    res.json(milestone);
  } catch (error) {
    res.status(500).send('Server error');
  }
};

const addMilestone = async (req, res) => {
  try {
    
    const newMilestone = await milestoneService.addMilestone(req.body);
    res.json(newMilestone);
  } catch (error) {
    console.error('Error in addMilestone:', error);
    if (error.message === 'Milestone with this name already exists') {
      res.status(400).send({ message: error.message });
    } else {
      res.status(400).send({ message: 'Validation error', details: error.message });
    }
  } 
};

const editMilestone = async (req, res) => {
  try {
    const id = req.params.id;
    if (!id) {
      return res.status(400).send('ID is required');
    }

    const updatedMilestone = await milestoneService.editMilestone(id, req.body);
    res.json(updatedMilestone);
  } catch (error) {
    res.status(400).send({ message: 'Milestone with this name already exists', details: error.message });
  }
};

const deleteMilestone = async (req, res) => {
  try {
    const id = req.params.id;
    if (!id) {
      return res.status(400).send('ID is required');
    }
    const deletedMilestone = await milestoneService.deleteMilestone(id);
    res.json({ message: 'Milestone soft deleted', deletedMilestone });
  } catch (error) {
    console.error(error);
    res.status(500).send('Server error');
  }
};

module.exports = {
  getMilestone,
  getMilestoneByID,
  addMilestone,
  editMilestone,
  deleteMilestone
};