const { Milestone } = require('../../../database/models/project/milestoneSchema');
const applySearchAndPagination = require('../../../utils/paginationAndSearch');

const findAllWithSearchAndPagination = async (search, page, limit) => {
  const searchFields = ['name', 'status'];
  const populateFields = [
    {
      path: 'project',
      select: 'name'
    }
  ];
  const baseQuery = { visibility: true };
  return await applySearchAndPagination(Milestone, searchFields, search, page, limit, populateFields, false, baseQuery);
};

const findByProjectId = async (projectId, search, page, limit) => {
  const searchFields = ['name', 'status'];
  const populateFields = [
    {
      path: 'project',
      select: 'name'
    }
  ];
  const baseQuery = { project: projectId, visibility: true };
  return await applySearchAndPagination(Milestone, searchFields, search, page, limit, populateFields, false, baseQuery);
};

const findById = async (id) => {
  return await Milestone.findOne({ _id: id, visibility: true }).populate('project', 'name');
};

const create = async (milestoneData) => {
  
  const existingMilestone = await Milestone.findOne({ name: milestoneData.name, project: milestoneData.project });
  
  
  if (existingMilestone) {
    if (existingMilestone.visibility === false) {
      return await Milestone.findOneAndUpdate(
        { _id: existingMilestone._id },
        { ...milestoneData, visibility: true },
        { new: true }
      ).populate('project', 'name');
    }
    throw new Error('Milestone with this name already exists');
  }
  
  const newMilestone = new Milestone(milestoneData);
  
  return await newMilestone.save();
};


// const create = async (milestoneData) => {
//   // Check if a milestone with the same name exists within the same project (including soft-deleted ones)
//   const existingMilestone = await Milestone.findOne({
//     project: milestoneData.project,
//     name: milestoneData.name,
//   });

//   if (existingMilestone) {
//     if (existingMilestone.visibility === false) {
//       // If it exists but is soft-deleted, update it instead of creating a new one
//       return await Milestone.findOneAndUpdate(
//         { _id: existingMilestone._id },
//         { ...milestoneData, visibility: true },
//         { new: true }
//       ).populate('project', 'name');
//     }
//     // If it exists and is visible, throw an error
//     throw new Error('Milestone with this name already exists in this project');
//   }

//   // If no existing milestone is found, create a new one
//   const newMilestone = new Milestone(milestoneData);
//   return await newMilestone.save();
// };

const updateById = async (id, milestoneData) => {
  return await Milestone.findOneAndUpdate(
    { _id: id, visibility: true },
    milestoneData,
    { new: true }
  ).populate('project', 'name');
};

const deleteById = async (id) => {
  return await Milestone.findByIdAndUpdate(id, { visibility: false }, { new: true });
};

module.exports = {
  findAllWithSearchAndPagination,
  findById,
  create,
  updateById,
  findByProjectId,
  deleteById
};