const resourceService = require('./Service/requsestResource.service');


exports.getAllPendingRequests = async (req, res) => {
  try {
    const { search, page = 1, limit = 25, fetchAll = false } = req.query;

    const pendingRequests = await resourceService.getAllPendingRequests(search, page, limit, fetchAll === 'true');

    res.json(pendingRequests);
  } catch (error) {
    console.error('Error fetching pending requests:', error);
    res.status(500).json({ message: 'Failed to fetch pending requests', error: error.message });
  }
};


exports.allocateResources = async (req, res) => {
  try {
    const { projectId, skillSet, numberOfEmployees, startDate, endDate, priority, requestedBy } = req.body;
  
    // Call the service to handle the allocation logic
    const result = await resourceService.allocateResources({
      projectId,
      skillSet, 
      numberOfEmployees,
      startDate,
      endDate,
      priority,
      requestedBy 
    });
  
    res.status(201).json({ message: 'Resources allocated successfully', data: result });
  } catch (error) {
    res.status(500).json({ message: 'Failed to allocate resources', error: error.message });
  }
};
  

exports.updateRequestStatus = async (req, res) => {
  try {
    const { id } = req.params;
    const { status, updatedEmployeeRole, allocatedEmployees, requestedEmployeeNames } = req.body;

    if (!id) {
      return res.status(400).json({ message: 'ID is required' });
    }

    // Convert status to title case (first letter uppercase, rest lowercase)
    const formattedStatus = status.charAt(0).toUpperCase() + status.slice(1).toLowerCase();

    if (!['Accepted', 'Rejected'].includes(formattedStatus)) {
      return res.status(400).json({ message: 'Invalid status. Must be \'Accepted\' or \'Rejected\'' });
    }

    const updatedRequest = await resourceService.updateRequestStatus(id, {
      status: formattedStatus,
      updatedEmployeeRole,
      allocatedEmployees,
      requestedEmployeeNames
    });

    res.status(200).json({ message: 'Request status updated successfully', data: updatedRequest });
  } catch (error) {
    console.error('Error updating request status:', error);
    res.status(500).json({ message: 'Failed to update request status', error: error.message });
  }
};
exports.getAllHistoryByProjectId = async (req, res) => {
  try {
    const { projectId } = req.params;
    const history = await resourceService.getAllHistoryByProjectId(projectId);

    res.status(200).json({
      message: 'History fetched successfully',
      data: history
    });
  } catch (error) {
    res.status(500).json({ message: 'Failed to fetch history', error: error.message });
  }
};

// Ensure this function is correctly exported


exports.getPendingRequestsByProjectId = async (req, res) => {
  try {
    const { id } = req.params;

    const pendingRequests = await resourceService.getPendingRequests(id);

    // Always return 200 OK, with an empty array if no requests are found
    res.status(200).json({
      message: pendingRequests.length > 0 
        ? true 
        : false,
      data: pendingRequests
    });
  } catch (error) {
    res.status(500).json({ message: 'Failed to fetch pending requests', error: error.message });
  }
};

  