const mongoose = require('mongoose');

const applySearchAndPagination = async (model, searchFields, searchQuery, page = 1, limit = 25, populateFields = [], fetchAll = false, baseQuery = {}) => {
  let query = { ...baseQuery };

  if (searchQuery) {
    query.$and = [
      { $or: await Promise.all(searchFields.map(async field => {
        const schemaType = model.schema.path(field.split('.')[0]);

        if (field.includes('.') && schemaType instanceof mongoose.Schema.Types.ObjectId) {
          const [refField, nestedField] = field.split('.');
          const refModel = model.db.model(schemaType.options.ref);
          const matchingIds = await refModel.find({ [nestedField]: { $regex: searchQuery, $options: 'i' } }).distinct('_id');
          return { [refField]: { $in: matchingIds } };
        } else if (!field.includes('.')) {
          return { [field]: { $regex: searchQuery, $options: 'i' } };
        }
      })) },
      baseQuery
    ];
  }

  try {
    let queryBuilder = model.find(query);

    if (!fetchAll) {
      const skip = (page - 1) * limit;
      queryBuilder = queryBuilder.skip(skip).limit(limit);
    }

    if (populateFields.length > 0) {
      populateFields.forEach(field => {
        queryBuilder = queryBuilder.populate({
          path: field.path,
          select: field.select || '',
          populate: field.populate || []
        });
      });
    }

    const [total, results] = await Promise.all([
      model.countDocuments(query),
      queryBuilder.exec()
    ]);

    return {
      total,
      page: fetchAll ? 1 : page,
      pageSize: fetchAll ? total : limit,
      results
    };
  } catch (error) {
    console.error('Error in applySearchAndPagination:', error);
    throw new Error('Database query failed');
  }
};

module.exports = applySearchAndPagination;
