const nodemailer = require('nodemailer');
const fs = require('fs');
const path = require('path');


// Function to read HTML template and replace placeholders
function getHtmlTemplate(templatePath, resetLink) {
  const logo = path.join(__dirname, 'logos.json');
  const logos = JSON.parse(fs.readFileSync(logo, 'utf8'));
  let template = fs.readFileSync(templatePath, 'utf8');
  template = template.replace('{{resetLink}}', resetLink);  // Inject the reset link
  template = template.replace('{{logo}}', logos.juntos);
  template = template.replace('{{lock}}', logos.lock);
  template = template.replace('{{BASE_URL}}', 'https://sour-coats-rescue.loca.lt');

  return template;
}

async function sendEmail(email, subject, resetLink) {
  try {
    // Ensure environment variables are set for security
    if (!process.env.FROM || !process.env.PASS || !process.env.SERVICE) {
      throw new Error('Missing required environment variables: USER, PASS, SERVICE');
    }
       
    const transporter = nodemailer.createTransport({
      service: process.env.SERVICE, // Use a secure email service like Gmail, Outlook, etc.
      port: 465, // Standard port for secure SMTP connection
      secure: true, // Enable TLS encryption for secure communication
      auth: {
        user: process.env.FROM,
        pass: process.env.PASS,
      },
    });


    // Path to your HTML template
    const templatePath = path.join(__dirname, './Eclipse/EclipseForgotPassword.html');
  
    // Get the HTML content with the reset link injected
    const htmlContent = getHtmlTemplate(templatePath, resetLink);


    await transporter.sendMail({
      from: process.env.FROM, // Sender email address
      to: email, // Recipient email address
      subject: subject,
      // text: text,
      html: htmlContent, // HTML body
    });

    console.log('Email sent successfully!');
  } catch (error) {
    console.error('Error sending email:', error.message);
  }
}

module.exports = sendEmail; // Export the function
