const nodemailer = require('nodemailer');
const fs = require('fs');
const path = require('path');
const BASE_URL = process.env.BASE_URL ;
// Function to read HTML template and replace placeholders
function getHtmlTemplate(templatePath, email, newPassword) {
  const logo = path.join(__dirname, 'logos.json');
  const logos = JSON.parse(fs.readFileSync(logo, 'utf8'));
  let template = fs.readFileSync(templatePath, 'utf8');
  template = template.replace('{{userEmail}}', email);       // Inject the email
  template = template.replace('{{userPassword}}', newPassword); // Inject the new password
  template = template.replace('{{loginLink}}', process.env.LIVE_URL); // Inject the login link from environment variable
  template = template.replace('{{logo}}', logos.juntos);
  template = template.replace('{{BASE_URL}}', BASE_URL);
  return template;
}

async function sendEmail(email, subject, newPassword) {
  try {
    // Ensure environment variables are set for security
    if (!process.env.FROM || !process.env.PASS || !process.env.SERVICE || !process.env.BASE_URL) {
      throw new Error('Missing required environment variables: FROM, PASS, SERVICE, BASE_URL');
    }
       
    const transporter = nodemailer.createTransport({
      service: process.env.SERVICE, // Use a secure email service like Gmail, Outlook, etc.
      port: 465, // Standard port for secure SMTP connection
      secure: true, // Enable TLS encryption for secure communication
      auth: {
        user: process.env.FROM,
        pass: process.env.PASS,
      },
    });

    // Path to your HTML template
    const templatePath = path.join(__dirname, './Eclipse/EclipseTeamPassword.html');

    // Get the HTML content with the email and new password injected
    const htmlContent = getHtmlTemplate(templatePath, email, newPassword);

    await transporter.sendMail({
      from: process.env.FROM, // Sender email address
      to: email, // Recipient email address
      subject: subject,
      html: htmlContent, // HTML body
    });

    console.log('Email sent successfully!');
  } catch (error) {
    console.error('Error sending email:', error.message);
  }
}

module.exports = sendEmail; // Export the function
